@@ -1,4 +1,4 @@
-# Copyright (c) 2001-2004 Twisted Matrix Laboratories.
+# Copyright (c) 2001-2008 Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -15,9 +15,10 @@ except ImportError:
 
 from twisted.internet import protocol
 from twisted.python import log
+from twisted.python.reflect import qual
 
 from twisted.conch import error
-import keys
+from twisted.conch.ssh import keys
 import transport, userauth, connection
 
 import random
@@ -36,30 +37,27 @@ class SSHFactory(protocol.Factory):
             log.msg('INSECURE: unable to disable core dumps.')
         if not hasattr(self,'publicKeys'):
             self.publicKeys = self.getPublicKeys()
-            warned = False
-            for keyType, value in self.publicKeys.items():
-                if isinstance(value, str):
-                    if not warned:
-                        warnings.warn("Returning a mapping from strings to "
-                                "strings from getPublicKeys() is "
-                                "deprecated.  Return a mapping from "
-                                "strings to Key objects instead.",
-                                DeprecationWarning, stacklevel=2)
-                        warned = True
-                    self.publicKeys[keyType] = keys.Key.fromString(value)
+        for keyType, value in self.publicKeys.items():
+            if isinstance(value, str):
+                warnings.warn("Returning a mapping from strings to "
+                        "strings from getPublicKeys()/publicKeys (in %s) "
+                        "is deprecated.  Return a mapping from "
+                        "strings to Key objects instead." %
+                        (qual(self.__class__)),
+                        DeprecationWarning, stacklevel=1)
+                self.publicKeys[keyType] = keys.Key.fromString(value)
         if not hasattr(self,'privateKeys'):
             self.privateKeys = self.getPrivateKeys()
-            warned = False
-            for keyType, value in self.privateKeys.items():
-                if not isinstance(value, keys.Key):
-                    if not warned:
-                        warnings.warn("Returning a mapping from strings to "
-                                "PyCrypto key objects from getPrivateKeys() "
-                                "is deprecated.  Return a mapping from "
-                                "strings to Key objects instead.",
-                                DeprecationWarning, stacklevel=2)
-                        warned = True
-                    self.privateKeys[keyType] = keys.Key(value)
+        for keyType, value in self.privateKeys.items():
+            if not isinstance(value, keys.Key):
+                warnings.warn("Returning a mapping from strings to "
+                        "PyCrypto key objects from "
+                        "getPrivateKeys()/privateKeys (in %s) "
+                        "is deprecated.  Return a mapping from "
+                        "strings to Key objects instead." %
+                        (qual(self.__class__),),
+                        DeprecationWarning, stacklevel=1)
+                self.privateKeys[keyType] = keys.Key(value)
         if not self.publicKeys or not self.privateKeys:
             raise error.ConchError('no host keys, failing')
         if not hasattr(self,'primes'):
